// http://fisheye5.cenqua.com/browse/~raw,r=1.11/glassfish/appserv-core/src/java/com/sun/enterprise/distributedtx/J2EETransaction.java
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER. Copyright 1997-2007 Sun Microsystems, Inc. All rights
 * reserved. The contents of this file are subject to the terms of either the GNU General Public License Version 2 only
 * ("GPL") or the Common Development and Distribution License("CDDL") (collectively, the "License"). You may not use
 * this file except in compliance with the License. You can obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL.html or glassfish/bootstrap/legal/LICENSE.txt. See the License for the
 * specific language governing permissions and limitations under the License. When distributing the software, include
 * this License Header Notice in each file and include the License file at glassfish/bootstrap/legal/LICENSE.txt. Sun
 * designates this particular file as subject to the "Classpath" exception as provided by Sun in the GPL Version 2
 * section of the License file that accompanied this code. If applicable, add the following below the License Header,
 * with the fields enclosed by brackets [] replaced by your own identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]" Contributor(s): If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor] elects to include this software in this
 * distribution under the [CDDL or GPL Version 2] license." If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under either the CDDL, the GPL Version 2 or to
 * extend the choice of license to its licensees as provided above. However, if you add GPL Version 2 code and
 * therefore, elected the GPL Version 2 license, then the option applies only if the new code is made subject to such
 * option by the copyright holder.
 */
package test;

import java.util.Timer;
import java.util.TimerTask;

/**
 * This class implements the JTA Transaction API for the J2EE RI. It is a wrapper over the JTS Transaction object that
 * provides optimized local transaction support when a transaction uses zero/one non-XA resource, and delegates to JTS
 * otherwise. This object can be in two states: local tx (jtsTx==null) or global (JTS) tx. If jtsTx!=null, all calls are
 * delegated to jtsTx. Time out capability is added to the local transactions. This class extends the TimerTask. When
 * the transaction needs to be timedout, this schedules with the timer. At the commit and rollback time, task will be
 * cancelled. If the transaction is timedout, run() method will be called and transaction will be marked for rollback.
 */
public final class MyTimerTask extends TimerTask {

   static private boolean isTimerInitialized = false;
   static private Timer timer = null;
   private final String[] values;

   static synchronized private void initializeTimer() {
      if (isTimerInitialized) {
         return;
      }
      timer = new Timer(true); // daemon
      isTimerInitialized = true;
   }

   // START: local transaction timeout
   public MyTimerTask(int timeout, int size) {
      if (!isTimerInitialized) {
         initializeTimer();
      }

      values = new String[size];
      for (int i = 0; i < values.length; i++) {
         values[i] = "Timer " + timeout + " Some random" + Math.random();
      }

      timer.schedule(this, timeout * 1000);
   }

   @Override
   public void run() {
      System.out.println("Timeouted");
   }

   static public int purgeTimer() {
      return timer.purge();
   }
}
